<?php

/**
 * @file
 * Contains the administrative functions of the blocks_placer module.
 */


/**
 * Menu callback for the admin settings page.
 */
function blocks_placer_admin_settings() {

  // Region selection.
  $theme = variable_get('theme_default', 'bartik');
  $regions_system = system_region_list($theme, REGIONS_VISIBLE);

  $form['blocks_placer_restricted_regions'] = array(
    '#type'  => 'select',
    '#title' => t('Disable regions in @active_theme', array('@active_theme' => $theme)),
    '#description' => t('Selected regions will <strong>not</strong> be available in the @module.', array('@module' => BLOCKS_PLACER_NAME_FRIENDLY)),
    '#default_value' => variable_get('blocks_placer_restricted_regions', array()),
    '#options' => $regions_system,
    '#size' => count($regions_system),
    '#multiple' => TRUE,
  );

  // Blocks to exclude (always on top).
  $query = db_select('block', 'b')->condition('theme', $theme);
  $query->addExpression("CONCAT(module, '_', delta)", 'delta');
  $result = $query->execute()->fetchCol();
  $blocks = array_combine($result, $result);

  $form['blocks_placer_topmost'] = array(
    '#type'  => 'select',
    '#title' => t('Blocks to keep topmost'),
    '#description' => t('Selected blocks will always be rendered first in regions.'),
    '#default_value' => variable_get('blocks_placer_topmost', array()),
    '#options' => $blocks,
    '#size' => 5,
    '#multiple' => TRUE,
  );

  $form['blocks_placer_block_weight'] = array(
    '#type' => 'textfield',
    '#title' => t('Block weights'),
    '#description' => 'A low weight places blocks before global blocks, for example "-500". A high weight places blocks after global blocks, for example "500". Use extreme values to be sure of placement.',
    '#default_value' => variable_get('blocks_placer_block_weight', -500),
    '#size' => 5,
  );

  // Set chosen container to full width.
  drupal_add_css('#edit_blocks_placer_topmost_chosen { width: 100% !important; }', 'inline');

  return system_settings_form($form);
}


/**
 * Menu callback for the region demo page.
 */
function blocks_placer_region_demo($theme = NULL) {
  drupal_add_css(drupal_get_path('module', 'blocks_placer') . '/css/blocks-placer.css');

  $output = ''
    . '<p><br>This page illustrates regions available for block placement.</p>'
    . '<p>Using the ' . BLOCKS_PLACER_NAME_FRIENDLY . ' you can place blocks in any of the regions outlined on this page.</p>'
    . '<p>Note that the block layout is determined by the theme and can vary between regions.</p>';

  return $output;
}
